@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include "weights.h"
+#include "teststatistics.h"
 
 using namespace Rcpp;
 
@@ -26,24 +27,18 @@ List power_cont(Function rxy,
   List dta=rxy(xparam(0),yparam(0));
   NumericVector x = as<NumericVector>(dta["x"]);
   NumericVector y = as<NumericVector>(dta["y"]);
-  NumericVector wx(x.length()), wy(y.length());
-  if(dta.length()==4) {
-    wx = as<NumericVector>(dta["wx"]);
-    wy = as<NumericVector>(dta["wy"]);
-  }  
   int nx=x.size(), ny=y.size(), n=nx+ny, nl=xparam.size();
   NumericVector TS_data;
-  if(typeTS==1) TS_data=TS(x, y);
-  if(typeTS==2) TS_data=TS(x, y,  wx, wy);
-  if(typeTS==3) TS_data=TS(x, y);
-  if(typeTS==4) TS_data=TS(x, y, TSextra);
+  TS_data = calcTS(dta, TS, typeTS, TSextra);
   int const nummethods=TS_data.size();
   int i, j, m, l, cn=-1;
-  NumericVector z(n), wz(n);
+  NumericVector wx(nx), wy(ny), z(n), wz(n);
   NumericMatrix realdta(B*nl, 1+nummethods), permdta(B*nl, 1+nummethods);
   NumericVector TS_perm(nummethods);
   IntegerVector Index(n);
 
+  bool withweights=false;
+  if(typeTS==2) withweights=true;
 /*l loop over values in xparam */  
   for(l=0;l<nl;++l) {
 /*m loop over simulation runs */  
@@ -54,38 +49,41 @@ List power_cont(Function rxy,
 /*  find test statistics for data  */                
       x = as<NumericVector>(dta["x"]);
       y = as<NumericVector>(dta["y"]);
+      if(withweights) {
+        wx = as<NumericVector>(dta["wx"]);
+        wy = as<NumericVector>(dta["wy"]);
+        
+      }
       for(i=0;i<nx;++i) {
         Index(i)=i;
         z(i)=x(i);
+        if(typeTS==2) wz(i)=wx(i);
       }  
       for(i=0;i<ny;++i) {
         Index(i+nx)=i+nx;
         z(i+nx)=y(i);
+        if(withweights) wz(i+nx)=wy(i);
       }
-      if(dta.length()==4) {
-        wx = as<NumericVector>(dta["wx"]);
-        wy = as<NumericVector>(dta["wy"]);
-      } 
-      if(typeTS==1) TS_data=TS(x, y);
-      if(typeTS==2) TS_data=TS(x, y,  wx, wy);
-      if(typeTS==3) TS_data=TS(x, y);
-      if(typeTS==4) TS_data=TS(x, y, TSextra);
+      TS_data = calcTS(dta, TS, typeTS, TSextra);
       realdta(cn,0)=xparam(l);
       for(j=0;j<nummethods;++j) realdta(cn,j+1)=TS_data(j);
 /*  find test statistics for permuted data   */ 
       Index = Rcpp::sample(Index, n);
       for(i=0;i<nx;++i) {
         x[i]=z[Index[i]];
-        if(dta.length()==4) wx[i]=wz[Index[i]]; 
+        if(withweights) wx[i]=wz[Index[i]]; 
       }  
       for(i=0;i<ny;++i) {
         y[i]=z[Index[i+nx]];
-        if(dta.length()==4) wy[i]=wz[Index[i+nx]];
+        if(withweights) wy[i]=wz[Index[i+nx]];
       }
-      if(typeTS==1) TS_perm=TS(x, y); 
-      if(typeTS==2) TS_perm=TS(x, y, wx, wy); 
-      if(typeTS==3) TS_perm=TS(x, y);   
-      if(typeTS==4) TS_perm=TS(x, y, TSextra);
+      dta["x"]=x;
+      dta["y"]=y;
+      if(withweights) {
+        dta["wx"]=wx;
+        dta["wy"]=wy;
+      }
+      TS_perm = calcTS(dta, TS, typeTS, TSextra);
       permdta(cn,0)=xparam(l);
       for(j=0;j<nummethods;++j) permdta(cn,j+1)=TS_perm(j);
     }  
